import request from '@/utils/request'
import { mediaRequest } from '@/utils/request'

/**
 * 广播设置相关接口
 * @param params
 * @returns {*|Promise|Promise<unknown>}
 */
export function getList(params) {
  return request({
    url: '/ncs/broadcast/page',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}

/** 新增广播 */
export function add(params) {
  return request({
    url: '/ncs/broadcast',
    method: 'POST',
    loading: true,
    data: params
  })
}

/** 删除广播 */
export function remove(params) {
  const ids = params.toString()
  return request({
    url: `/ncs/broadcast/${ids}`,
    method: 'DELETE',
    loading: true,
    data: params
  })
}

/** 更新广播 */
export function update(id, params) {
  return request({
    url: `/ncs/broadcast/${id}`,
    method: 'put',
    data: params
  })
}

/** 查询单个广播 */
export function get(id, params) {
  return request({
    url: `/ncs/broadcast/${id}`,
    method: 'get',
    loading: false,
    params
  })
}

/** 查询某科室下的指定区域广播信息 */
export function getBoardCast(partid, zoneIndex) {
  return request({
    url: `/mgr/zoneinfo/${partid}/${zoneIndex}`,
    method: 'get',
    loading: false
  })
}
/**  更新指定科室的指定区域广播信息 */
export function updateBroadCast(partid, zoneIndex, params) {
  return request({
    url: `/mgr/zoneinfo/${partid}/${zoneIndex}`,
    method: 'put',
    loading: false,
    data: params
  })
}

/** 查询某个科室的广播音频文件列表 */
export function getZoneFileList(partid) {
  return request({
    url: `/mgr/zoneinfofilelist/${partid}`,
    method: 'get',
    loading: false
  })
}
/** 删除某科室下的音频文件 */
export function deleteZoneFile(partid, params) {
  return request({
    url: `/mgr/zoneinfo/delete/${partid}`,
    method: 'post',
    loading: false,
    data: params
  })
}

/** 获取音频文件虚拟目录 */
export function getZoneVirtualDir() {
  return request({
    url: '/mgr/zoneinfovirtualdir',
    method: 'get',
    loading: false
  })
}

/** 广播音频 */
export function broadCast(params) {
  return request({
    url: '/mgr/broadcast',
    method: 'post',
    loading: false,
    data: params
  })
}

/** 设置或获取广播音量 */
export function broadVol(params) {
  return request({
    url: '/WDHS-I/callingMainNurse_BroadcastVol',
    method: 'post',
    loading: false,
    data: params
  })
}

export function manulStart(id) {
  return mediaRequest({
    method: 'get',
    url: `/streaming/manul_start/${id}`
  })
}

export function manulStop(part_id, id) {
  return mediaRequest({
    method: 'get',
    url: `/streaming/manul_stop/${part_id}/${id}`
  })
}

export function auditionStart(id) {
  return mediaRequest({
    method: 'get',
    url: `/streaming/audition_start/${id}`
  })
}

export function auditionStop(part_id) {
  return mediaRequest({
    method: 'get',
    url: `/streaming/audition_stop/${part_id}`
  })
}

export function playAudio(id, part_id) {
  return request({
    method: 'get',
    url: `/ncs/broadcast/play_audio/${id}/${part_id}`
  })
}

export function stopAudio(id, part_id) {
  return request({
    method: 'get',
    url: `/ncs/broadcast/stop_audio/${id}/${part_id}`
  })
}

export function getBroadcastFileList(id) {
  return request({
    method: 'get',
    url: `/ncs/broadcast/get_broadcast_file_list/${id}`
  })
}
