import request from '@/utils/request'

/**
 * 获取授权信息
 * @param {String} departmentId 科室ID（可选）
 * @returns {Promise}
 */
export function getLicenseInfo(departmentId) {
  return request({
    url: '/lc/license-info',
    method: 'get',
    params: {
      departmentId
    }
  })
}

/**
 * 获取科室授权信息
 * @param {Number} partId 科室ID
 * @returns {Promise}
 */
export function getPartLicenseInfo(partId) {
  return request({
    url: `/part/settings/${partId}`,
    method: 'get'
  })
}

/**
 * 上传科室授权文件
 * @param {Object} data 参数对象
 * @param {File} data.zipFile 授权ZIP文件
 * @param {String} data.departmentId 科室ID
 * @returns {Promise}
 */
export function uploadPartLicense(data) {
  const formData = new FormData()
  formData.append('zipFile', data.zipFile)
  formData.append('departmentId', data.departmentId)

  return request({
    url: '/lc/upload',
    method: 'post',
    data: formData,
    headers: {
      // 'Content-Type': 'multipart/form-data' // 删除这一行，让浏览器自动设置
    },
    transformRequest: [function(data) {
      return data // 返回原始FormData，不进行任何转换
    }]
  })
}

/**
 * 清除授权缓存
 * @returns {Promise}
 */
export function clearLicenseCache() {
  return request({
    url: '/lc/clear-cache',
    method: 'post'
  })
}

/**
 * 查询授权期限
 * @returns {Promise}
 */
export function getLicenseExpire() {
  return request({
    url: '/lc/expire',
    method: 'get'
  })
}

/**
 * 获取服务器硬件指纹
 * @returns {Promise}
 */
export function getHardwareFingerprint() {
  return request({
    url: '/lc/hardware-fingerprint',
    method: 'get'
  })
}

/**
 * 获取开发环境的简化硬件指纹
 * @returns {Promise}
 */
export function getSimpleFingerprint() {
  return request({
    url: '/lc/simple-fingerprint',
    method: 'get'
  })
} 