import request from '@/utils/request'

/**
 * 对讲频道相关接口
 * @param params
 * @returns {*|Promise|Promise<unknown>}
 */
export function getList(params) {
  return request({
    url: '/ncs/channel/page',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}

/** 新增对讲频道 */
export function add(params) {
  return request({
    url: '/ncs/channel',
    method: 'POST',
    loading: true,
    data: params
  })
}

/** 删除对讲频道 */
export function remove(params) {
  const ids = params.toString()
  return request({
    url: `/ncs/channel/${ids}`,
    method: 'DELETE',
    loading: true,
    data: params
  })
}

/** 更新对讲频道 */
export function update(id, params) {
  return request({
    url: `/ncs/channel/${id}`,
    method: 'put',
    data: params
  })
}

/** 查询对讲频道 */
export function get(id, params) {
  return request({
    url: `/ncs/channel/${id}`,
    method: 'get',
    loading: false,
    params
  })
}

/**
 * 获取频道的订阅者列表 返回List<ClerkDO> 或null
 * @param id 频道Id
 * @returns {AxiosPromise | * | Promise | Promise<unknown>}
 */
export function getChannelSubscribers(id) {
  return request({
    url: `/channelsubscribe/subscribers/${id}`,
    method: 'get',
    loading: false
  })
}

/**
 * 批量设置频道订阅者
 * @param params {channel_id:12,member_ids:[]}
 * @returns {*|Promise|Promise<unknown>}
 */
export function setChannelSubscribers(params) {
  return request({
    url: `/channelsubscribe/subscribers`,
    method: 'post',
    loading: false,
    data: params
  })
}
