/**
 * 设备信息接口请求
 * @param params
 * @returns {Promise<any>}
 */
import request from '@/utils/request'
export function getList(params) {
  return request({
    url: '/ncs/device/page',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}

/** 新增设备 */
export function add(params) {
  return request({
    url: '/ncs/device',
    method: 'POST',
    loading: true,
    data: params
  })
}

/** 新增虚拟设备 */
export function addVirtualDevice(params) {
  return request({
    url: '/ncs/virtualdevice',
    method: 'POST',
    loading: true,
    data: params
  })
}

/** 删除设备 */
export function remove(params) {
  const ids = params.toString()
  return request({
    url: `/ncs/device/${ids}`,
    method: 'DELETE',
    loading: true,
    data: params
  })
}

/** 更新设备 */
export function update(id, params) {
  return request({
    url: `/ncs/device/${id}`,
    method: 'put',
    data: params
  })
}

/** 更新设备 */
export function getDeviceById(id) {
  return request({
    url: `/ncs/device/${id}`,
    method: 'get'
  })
}

/** 查询某类设备 */
export function getDeviceByType(partid, type) {
  return request({
    url: `/ncs/device/getNurseDeviceList/${partid}/${type}`,
    method: 'get',
    loading: false
  })
}
/** 查询某个主机下的某类设备 */
export function getSubDevices(hostid, type) {
  return request({
    url: `/ncs/subdevice/${hostid}/${type}`,
    method: 'get',
    loading: false
  })
}
/** 获取DHCP服务器下一个可分配地址 */
export function getNextIP() {
  return request({
    url: '/ncs/device/getnextip',
    method: 'get',
    loading: false
  })
}

/** 获取APP版本更新信息 */
export function getAPPVersion(params) {
  return request({
    url: '/ncs/app_version/getappversion',
    method: 'get',
    loading: false,
    params
  })
}
/** 设置APP版本更新信息 **/
export function setAPPVersion(params) {
  return request({
    url: '/ncs/app_version/setappversion',
    method: 'post',
    loading: false,
    data: params
  })
}

export function getBoardPage(params) {
  return request({
    url: '/InfoBoard/board_list',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}

export function saveBoard(params) {
  return request({
    url: '/InfoBoard/save_board',
    method: 'POST',
    loading: true,
    data: params
  })
}

/** 写入分机测试数据 */
export function addTestData() {
  return request({
    url: '/ncs/testdata',
    method: 'POST',
    loading: true
  })
}

/** 擦除分机测试数据 */
export function deleteTestData() {
  return request({
    url: '/ncs/testdata',
    method: 'DELETE',
    loading: true
  })
}

/** 更新设备排序，按房号，床号，排序，护士主机可按顺序显示 */
export function updateDeviceIndex() {
  return request({
    url: '/ncs/updatedeviceindex',
    method: 'POST',
    loading: true
  })
}

/** 擦除分机测试数据 */
export function updateByIds(params) {
  return request({
    url: `/ncs/device/updateByIds`,
    method: 'POST',
    loading: true,
    data: params
  })
}
export function getFrameByDeviceId(id) {
  return request({
    url: `/ncs/device/getFrameByDeviceId/${id}`,
    method: 'GET',
    loading: false
  })
}
export function listByHospital(params) {
  return request({
    url: '/ncs/device/listByHospital',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}

export function getManageHostDeviceByHospitalId(hospitalId) {
  return request({
    url: `/ncs/device/get_manage_host_device_by_hospital_id/${hospitalId}`,
    method: 'GET',
    loading: false
  })
}

export function get485DeviceAndFrame(partId, tid) {
  return request({
    url: `/ncs/device/get_485_device_and_frame/${partId}/${tid}`,
    method: 'GET',
    loading: false
  })
}

export function getDeviceByHasNoFrameId(partId) {
  return request({
    url: `/ncs/device/get_device_by_has_no_frame_id/${partId}`,
    method: 'GET',
    loading: false
  })
}
export function updateDevicesFrame(data) {
  return request({
    url: `/ncs/device/update_devices_frame`,
    method: 'POST',
    data: data,
    headers: { 'Content-Type': 'application/json' },
    loading: true
  })
}

export function delAllDeviceFrame(id, parentId) {
  return request({
    url: `/ncs/device/del_all_device_frame/${id}/${parentId}`,
    method: 'GET',
    loading: true
  })
}

export function updateDevicesServerIp(data) {
  return request({
    url: `/ncs/device/update_devices_server_ip`,
    method: 'POST',
    data: data,
    headers: { 'Content-Type': 'application/json' },
    loading: true
  })
}

export function getOtherHostDevice(partId) {
  return request({
    url: `/ncs/device/get_other_host_device/${partId}`,
    method: 'GET',
    loading: false
  })
}

export function update485s(data) {
  return request({
    url: `/ncs/device/update485s`,
    method: 'POST',
    data: data,
    loading: true
  })
}

export function getCacheListByType(partId, deviceType) {
  return request({
    url: `/ncs/device/getCacheListByType/${partId}/${deviceType}`,
    method: 'GET',
    loading: true
  })
}


export function openDebug(id){
  return request({
    url: `/ncs/device/opendebug/${id}`,
    method: 'get'
  })
}

export function rebootDevice(id){
  return request({
    url: `/ncs/device/reboot/${id}`,
    method: 'get'
  })
}

export function getWatchFootprint(memberId, deviceType){
  return request({
    url: `/ncs/device/getWatchFootprint/${memberId}/${deviceType}`,
    method: 'get'
  })
}

/** 查询定位设备 */
export function getLocationDeviceList(partid) {
  return request({
    url: `/ncs/device/getLocationDeviceList/${partid}`,
    method: 'get',
    loading: false
  })
}

export function getDeviceList(frameId, type) {
  return request({
    url: `/ncs/device/getDeviceList/${frameId}/${type}`,
    method: 'get',
    loading: false
  })
}
export function getDevicePositionList(frameId, types) {
  return request({
    url: `/ncs/device/getDeviceListByTypes/${frameId}`,
    method: 'post',
    headers: { 'Content-Type': 'application/json' },
    data: types,
    loading: false
  })
}
/** 获取转换盒存储的按钮 */
export function getLoraButtons(mac) {
  return request({
    url: `/ncs/device/get_lora_buttons/${mac}`,
    method: 'get',
    loading: false
  })
}
/** 刷新转换盒存储的按钮 */
export function refreshLoraButtons(mac) {
  return request({
    url: `/ncs/device/refresh_lora_buttons/${mac}`,
    method: 'get',
    loading: false
  })
}
/** 转换盒添加按钮 */
export function addLoraButtons(mac, lora_list) {
  return request({
    url: `/ncs/device/add_lora_buttons/${mac}/${lora_list}`,
    method: 'get',
    loading: false
  })
}
/** 转换盒删除按钮 */
export function delLoraButtons(mac, lora_mac) {
  return request({
    url: `/ncs/device/del_lora_buttons/${mac}/${lora_mac}`,
    method: 'get',
    loading: false
  })
}
/** 转换盒清空存储的按钮 */
export function delAllLoraButtons(mac) {
  return request({
    url: `/ncs/device/del_all_lora_buttons/${mac}`,
    method: 'get',
    loading: false
  })
}

