
import request from '@/utils/request'
/**
 * 医院结构相关API
 */
/**
 * 获取医院结构列表
 */
export function getHospitalFrameList(id) {
  return request({
    url: `/ncs/frame/${id}`,
    method: 'GET',
    loading: false,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}
/** 根据空间类型查找空间 */
export function getFrameByPartIdAndFrameType(partId, frameType) {
  return request({
    url: `/ncs/frame/getFrameByPartIdAndFrameType/${partId}/${frameType}`,
    loading: false,
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
  })
}
/** 新增医院结构 */
export function addHospitalFrame(params) {
  // params = JSON.parse(JSON.stringify(params))
  return request({
    url: '/ncs/frame',
    method: 'POST',
    loading: true,
    data: params
  })
}
/** 删除医院结构 */
export function deleteHospitalFrame(params) {
  const ids = params.toString()
  return request({
    url: `/ncs/frame/${ids}`,
    method: 'DELETE',
    loading: true,
    data: params
  })
}
/** 更新医院结构信息 */
export function updateHospitalFrame(id, params) {
  return request({
    url: `/ncs/frame/${id}`,
    method: 'put',
    data: params
  })
}

export function getFrameWithPatientAndDeviceVO() {
  return request({
    url: '/care/hospital_frame/frame_with_patient_and_device',
    method: 'get',
    loading: true
  })
}

export function getAllSickbed(id) {
  return request({
    url: `/ncs/frame/get_all_sick_bed/${id}`,
    method: 'GET',
    loading: false
  })
}

export function getSickbedByPartId(id) {
  return request({
    url: `/ncs/frame/getSickbedByPartId/${id}`,
    method: 'GET',
    loading: false
  })
}

export function quickCreate(params) {
  return request({
    url: '/ncs/frame/quickcreate',
    method: 'POST',
    loading: false,
    data: params
  })
}

export function renameBeds(part_id,params) {
  return request({
    url: `/ncs/frame/renamebedname/${part_id}`,
    method: 'POST',
    loading: false,
    data: params
  })
}
export function renameRooms(part_id,params) {
  return request({
    url: `/ncs/frame/renameroomname/${part_id}`,
    method: 'POST',
    loading: false,
    data: params
  })
}

/** 拖拽排序frame */
export function sort(source_id, target_id, relation) {
  return request({
    url: `/ncs/frame/sort`,
    method: 'post',
    loading: false,
    data: {
      frame_id: source_id,
      target_id: target_id,
      relation: relation
    }
  })
}

export function getFramesPartId(part_id) {
  return request({
    url: `/ncs/frame/frames/${part_id}`,
    method: 'GET',
    loading: false
  })
}

export function getAllFrames() {
  return request({
    url: `/ncs/frame/all_frames`,
    method: 'GET',
    loading: false
  })
}

export function getFramesHospital(hospital_id) {
  return request({
    url: `/ncs/frame/getFramesByHospitalId/${hospital_id}`,
    method: 'GET',
    loading: false
  })
}
export function getFrameByType(id, deviceId, roleId) {
  return request({
    url: `/ncs/frame/getFrameByType/${id}/${deviceId}/${roleId}`,
    method: 'GET',
    loading: false
  })
}
export function getFrameByRoleId(id, roleId) {
  return request({
    url: `/ncs/frame/getFrameByRoleId/${id}/${roleId}`,
    method: 'GET',
    loading: false
  })
}
export function getFrameByRoleGroupId(id, memberId) {
  return request({
    url: `/ncs/frame/getFrameByRoleGroupId/${id}/${memberId}`,
    method: 'GET',
    loading: false
  })
}
export function updateDeviceFrameManage(params) {
  return request({
    url: '/ncs/frame/updateDeviceFrameManage',
    method: 'POST',
    loading: true,
    data: params,
    headers: { 'Content-Type': 'application/json' }
  })
}
/** 清空 */
export function qingkong(id) {
  return request({
    url: `/ncs/frame/qingkong/${id}`,
    method: 'DELETE',
    loading: true
  })
}
// 查询设备（信标）所在的空间
export function getListByDeviceId(id) {
  return request({
    url: `/ncs/frame/getListByDeviceId/${id}`,
    method: 'GET',
    loading: false
  })
}
// 获取空间及其设备
export function getFrameAndDevice(id) {
  return request({
    url: `/ncs/frame/get_frame_and_device/${id}`,
    method: 'GET',
    loading: false
  })
}

/** 查询某科室下的房间结构 */
export function getframestruct(part_id, frame_type) {
  return request({
    url: `/ncs/frame/getframestruct/${part_id}/${frame_type}`,
    method: 'get',
    loading: false
  })
}

/** 查询某科室下的房间结构 */
export function getAllFrameTreeByType(frame_type) {
  return request({
    url: `/ncs/frame/getAllFrameTreeByType/${frame_type}`,
    method: 'get',
    loading: false
  })
}

/** 查询空间结构的管理人员信息 */
export function getFrameManagedClerk(frameId) {
  return request({
    url: `/ncs/frame/getframemanagedclerk/${frameId}`,
    method: 'get',
    loading: false
  })
}

/** 保存空间结构的管理人员信息 */
export function saveFrameManagedClerk(params) {
  return request({
    url: `/ncs/frame/saveframemanagedclerk`,
    method: 'POST',
    loading: true,
    headers: { 'Content-Type': 'application/json' },
    data: params
  })
}

/** 查询某科室下多人共管的房间结构 */
export function getframemultimanagedstruct(part_id, frame_type) {
  return request({
    url: `/ncs/frame/getframemultimanagedstruct/${part_id}/${frame_type}`,
    method: 'get',
    loading: false
  })
}
