import request from '@/utils/request'

/** 获取华屹睡眠检测仪的id */
export function getDeviceId(device_code) {
  return request({
    url: `/huayisleep/device_id/${device_code}`,
    method: 'GET'
  })
}

/** 获取设备的状态 */
export function getDeviceStatus(device_code) {
  return request({
    url: `/huayisleep/device_status/${device_code}`,
    method: 'GET'
  })
}

/** 获取睡眠分析的参考值 */
export function getSleepReference(reference_type) {
  return request({
    url: `/huayisleep/sleep_reference/${reference_type}`,
    method: 'GET'
  })
}

/** 获取设备参数 */
export function getDeviceParams(third_party_id) {
  return request({
    url: `/huayisleep/device_params/${third_party_id}`,
    method: 'GET'
  })
}

/** 设备离床预警设置 */
export function setDeviceSettings(third_party_id, action_code, deviceSettings) {
  return request({
    url: `/huayisleep/device_settings/${third_party_id}/${action_code}`,
    method: 'POST',
    data: deviceSettings,
    headers: { 'Content-Type': 'application/json' }
  })
}

/** 每日心率统计 */
export function getDailyHeartRate(third_party_id, date, date_format = 'MINUTE') {
  return request({
    url: `/huayisleep/daily_heart_rate/${third_party_id}`,
    method: 'GET',
    params: { date, date_format }
  })
}

/** 每日呼吸统计 */
export function getDailyBreath(third_party_id, date, date_format = 'MINUTE') {
  return request({
    url: `/huayisleep/daily_breath/${third_party_id}`,
    method: 'GET',
    params: { date, date_format }
  })
}

/** 每日睡眠统计 */
export function getDailySleep(third_party_id, date) {
  return request({
    url: `/huayisleep/daily_sleep/${third_party_id}`,
    method: 'GET',
    params: { date }
  })
}

/** 获取历史心率数据 */
export function getHistoryHeartRate(third_party_id, date_format, start_date, end_date) {
  return request({
    url: `/huayisleep/history_heart_rate/${third_party_id}`,
    method: 'GET',
    params: { date_format, start_date, end_date }
  })
}

/** 体动统计 */
export function getMovementData(third_party_id, start_time, end_time, page, page_size) {
  return request({
    url: `/huayisleep/movement/${third_party_id}`,
    method: 'GET',
    params: { start_time, end_time, page, page_size }
  })
}

/** 获取历史呼吸数据 */
export function getHistoryBreath(third_party_id, date_format, start_date, end_date) {
  return request({
    url: `/huayisleep/history_Breath/${third_party_id}`,
    method: 'GET',
    params: { date_format, start_date, end_date }
  })
}

/** 获取历史呼吸数据（按年来统计） */
export function getYearlyHistoryBreath(third_party_id, date_format, start_date, end_date) {
  return request({
    url: `/huayisleep/yearly_history_breath/${third_party_id}`,
    method: 'GET',
    params: { date_format, start_date, end_date }
  })
}

/** 获取历史睡眠数据 */
export function getHistorySleep(third_party_id, date_format, start_date, end_date) {
  return request({
    url: `/huayisleep/history_sleep/${third_party_id}`,
    method: 'GET',
    params: { date_format, start_date, end_date }
  })
}