import request from '@/utils/request'
import Storage from '@/utils/storage'
import store from '@/store'
import md5 from 'js-md5'
export function login(data) {
  data.password = md5(data.password)
  return request({
    url: '/Mgr/login',
    method: 'get',
    params: data
  })
}

export function logout(data) {
  return request({
    url: '/Mgr/logout',
    method: 'post',
    data: {
      uid: store.getters.userInfo.uid
    }
  })
}
/**
 * 刷新用户token
 * @param data refresh_token=token
 * @returns {AxiosPromise | * | Promise<unknown>}
 */
export function refreshToken(data) {
  return request({
    url: '/Mgr/refresh_token',
    method: 'post',
    loading: false,
    data: {
      refresh_token: Storage.getItem('calling_refresh_token')
    }
  })
}

export function getInfo(token) {
  return request({
    url: '/vue-element-admin/user/info',
    method: 'get',
    params: { token }
  })
}

export function getList(data) {
  return request({
    url: '/Mgr/member/page',
    method: 'POST',
    params: data,
    loading: false
  })
}

export function add(params) {
  return request({
    url: '/Mgr/member/add',
    method: 'POST',
    data: params
  })
}

export function addRelative(params) {
  return request({
    url: '/Mgr/member/add_relative',
    method: 'POST',
    data: params
  })
}

export function remove(params) {
  const ids = params.toString()
  return request({
    url: `/Mgr/member/${ids}`,
    method: 'DELETE',
    loading: false,
    data: params
  })
}

export function getUnionId(memberId) {
  return request({
    url: `/Mgr/member/get_union_id/${memberId}`,
    method: 'GET'
  })
}

/**
 * 获取用户角色权限
 * @param role_id
 * @returns {*}
 */
export function getUserRolesPermissions(role_id) {
  return request({
    url: `/mgr/role/${role_id}/checked`,
    method: 'get'
  })
}

