
import './index.css'
// 自定义音频block工具
export default class AudioTool {
  constructor({ data, block, config,api }) {
    /**
         * Nodes cache
         */
    this.api=api
    this.nodes = {
      wrapper: null,
      audio: null,
      plusHolder: null,
      popOver: null
    }

    this.data = {
      src: data.src || '',
      withBorder: data.withBorder !== undefined ? data.withBorder : false,
      withBackground: data.withBackground !== undefined ? data.withBackground : false,
      stretched: data.stretched !== undefined ? data.stretched : false

    }
    // console.log('thisdata', this.data)
    this.config = config
    this.block = block
  }

  static get toolbox() {
    return {
      title: 'AudioPlayer',
      icon: '<?xml version="1.0" standalone="no"?><!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd"><svg t="1711606441145" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="4963" width="32" height="32" xmlns:xlink="http://www.w3.org/1999/xlink"><path d="M551.936 781.098667c16.682667 62.208-37.056 130.645333-119.978667 152.874666-82.944 22.208-163.690667-10.197333-180.352-72.405333-16.682667-62.208 37.056-130.645333 119.978667-152.874667 82.944-22.208 163.690667 10.197333 180.352 72.405334z" fill="#000000" p-id="4964"></path><path d="M554.666667 85.333333v725.333334h-42.666667V85.333333h42.666667z" fill="#000000" p-id="4965"></path><path d="M554.666667 85.333333v21.333334c0 15.829333 7.04 37.098667 21.461333 61.589333 14.165333 24.085333 34.304 49.344 57.621333 72.661333 8.32 8.298667 17.28 16.874667 26.581334 25.770667 24.746667 23.637333 51.712 49.365333 73.770666 77.461333C765.290667 383.829333 789.333333 431.018667 789.333333 490.666667c0 45.888-11.392 93.696-25.173333 133.632-13.738667 39.829333-30.442667 73.6-42.410667 91.52l-11.84 17.770666-35.498666-23.68 11.84-17.749333c9.386667-14.058667 24.661333-44.288 37.589333-81.792C736.725333 572.970667 746.666667 530.133333 746.666667 490.666667c0-47.018667-18.624-85.162667-46.101334-120.149334-20.053333-25.536-43.541333-47.957333-67.477333-70.826666-9.813333-9.386667-19.733333-18.837333-29.504-28.586667-25.344-25.365333-47.872-53.44-64.213333-81.194667C523.285333 162.56 512 133.504 512 106.666667V85.333333h42.666667z" fill="#000000" p-id="4966"></path></svg>'
    }
  }

  changeImageUrl(url) {
    this.data = {
      src: url
    }
  }

  render() {
    this.nodes.wrapper = document.createElement('div')
    this.nodes.audio = this._make('audio','',{style:'display:none'})
    this.nodes.wrapper.classList.add('wrapper')
    this.nodes.audio.setAttribute('controls', 'controls')
    this.nodes.plusHolder = this._make('div', 'cdx-plus-holder', {
      onclick: () => {
        this.config.onChoose(this.block.id,this.api.blocks.getCurrentBlockIndex())
      }
    })
    const plus = this._make('i', ['el-icon-plus'], {})
    this.nodes.plusHolder.appendChild(plus)
    // this.nodes.input.type = 'text'
    // this.nodes.input.name = 'audioUrl'
    // this.nodes.input.placeholder = 'Enter your url of audio file'
    // this.nodes.input.value = this.data.src ? this.data.src : ''
    // this.nodes.input.classList.add('input')
    // this.nodes.input.addEventListener('change', () => {
    //   const src = this.nodes.input?.value
    //   if (src) {
    //     this.nodes.audio.setAttribute('src', src)
    //   } else {
    //     this.nodes.audio.removeAttribute('src')
    //   }
    // })
    if (this.data.src) {
      this.nodes.audio.setAttribute('src', this.data.src)
    }
    // const { src } = this.data
    // if (src) {
    //
    // }

    // this.nodes.wrapper.appendChild(this.nodes.input)
    this.nodes.wrapper.appendChild(this.nodes.audio)
    this.nodes.wrapper.appendChild(this.nodes.plusHolder)

    if (this.data.src) {
      this.nodes.audio.src = this.data.src
      this.nodes.plusHolder.style.display = 'none'
      this.nodes.audio.style.display = 'block'
      // console.log(this.nodes.audio)
    } else {
      this.nodes.audio.style.display = 'none'
      this.nodes.plusHolder.style.display = 'block'
    }

    return this.nodes.wrapper
  }

  save(blockContent) {
    const src = blockContent.querySelector('audio').src

    return {
      src
    }
  }

  validate(savedData) {
    if (savedData.src === '' && !savedData.src.trim()) {
      return false
    }

    return true
  }

  _make(tagName, classNames = null, attributes = {}) {
    const el = document.createElement(tagName)

    if (Array.isArray(classNames)) {
      el.classList.add(...classNames)
    } else if (classNames) {
      el.classList.add(classNames)
    }

    for (const attrName in attributes) {
      el[attrName] = attributes[attrName]
    }

    return el
  }

  get data() {
    return this._data
  }
  static get isReadOnlySupported() {
    return true
  }
  set data(data) {
    this._data = Object.assign({}, this.data, data)
    // console.log('_data', this._data)
    if (this.nodes.audio) {
      if (this._data.src) {
        this.nodes.audio.src = this._data.src
        this.nodes.plusHolder.style.display = 'none'
        this.nodes.audio.style.display = 'block'
        // console.log(this.nodes.audio)
      } else {
        this.nodes.audio.style.display = 'none'
        this.nodes.plusHolder.style.display = 'block'
      }
    }
  }
}
