import './index.css'
import { IconAddBorder, IconStretch, IconAddBackground } from '@codexteam/icons'
// 自定义图片Block 工具
export default class ImageTool {
  // eslint-disable-next-line no-useless-constructor
  constructor({ data, config, api, readOnly, block }) {
    this.api = api
    this.config = config
    this.readOnly = readOnly
    this.nodes = {
      wrapper: null,
      imageHolder: null,
      image: null,
      caption: null,
      plusHolder: null,
      popOver: null
    }
    this.data = {
      url: data.url || '',
      caption: data.caption || '',
      withBorder: data.withBorder !== undefined ? data.withBorder : false,
      withBackground: data.withBackground !== undefined ? data.withBackground : false,
      stretched: data.stretched !== undefined ? data.stretched : false
    }
    this.block = block

    this.CSS = {
      baseClass: this.api.styles.block,
      buttonClass: this.api.styles.button,
      input: this.api.styles.input,

      /**
           * Tool's classes
           */
      wrapper: 'cdx-simple-image',
      imageHolder: 'cdx-simple-image__picture',
      caption: 'cdx-simple-image__caption'
    }
    // console.log('api.i18n', this.api.i18n)

    this.tunes = [
      {
        name: 'withBorder',
        label: 'Add Border',
        icon: IconAddBorder
      },
      {
        name: 'stretched',
        label: 'Stretch Image',
        icon: IconStretch
      },
      {
        name: 'withBackground',
        label: 'Add Background',
        icon: IconAddBackground
      }
    ]
  }
  changeImageUrl(url) {
    this.data = {
      url: url
    }
  }
  render(data) {
    // console.log(this.block)
    const wrapper = this._make('div', [this.CSS.baseClass, this.CSS.wrapper],)
    const plusHolder = this._make('div', 'cdx-plus-holder', { onclick: () => { if (!this.readOnly) { this.config.onChoose(this.block.id) } }
    })
    const plus = this._make('i', ['el-icon-plus'], {})
    plusHolder.appendChild(plus)
    const imageHolder = this._make('div', this.CSS.imageHolder, { onmouseenter: (e) => {
      e.stopPropagation()
      if (this.nodes.popOver.style.display === 'block') return; if (this.data.url) { this.nodes.popOver.style.display = 'block' }
    },
    onmouseleave: (e) => {
      e.stopPropagation()
      this.nodes.popOver.style.display = 'none'
    } })
    const image = this._make('img', null)
    // const caption = this._make('div', [this.CSS.input, this.CSS.caption], {
    //   contentEditable: !this.readOnly,
    //   innerHTML: this.data.caption || ''
    // })

    const popover = this._make('div', ['el-loading-mask'], '')
    const poparrow = this._make('div', ['el-loading-spinner'])
    const rechooseButton = this._make('button', [this.CSS.buttonClass], { innerHTML: this.api.i18n.t('Reselection Image'),
      onclick: () => {
        this.config.onChoose(this.block.id,this.api.blocks.getCurrentBlockIndex())
      } })

    poparrow.appendChild(rechooseButton)

    popover.appendChild(poparrow)
    wrapper.appendChild(plusHolder)
    imageHolder.appendChild(image)
    wrapper.appendChild(imageHolder)
    imageHolder.appendChild(popover)

    this.nodes.imageHolder = imageHolder
    this.nodes.wrapper = wrapper
    this.nodes.image = image
    this.nodes.plusHolder = plusHolder
    this.nodes.popOver = popover
    this.nodes.popOver.style.display = 'none'

    if (this.readOnly) {
      this.nodes.plusHolder.style.display = 'none'
      this.nodes.imageHolder.onmouseleave = null
      this.nodes.imageHolder.onmouseenter = null
    } else {
      if (this.data.url) {
        this.nodes.image.src = this.data.url
        this.nodes.plusHolder.style.display = 'none'
      }
    }

    return wrapper
  }

  _make(tagName, classNames = null, attributes = {}) {
    const el = document.createElement(tagName)

    if (Array.isArray(classNames)) {
      el.classList.add(...classNames)
    } else if (classNames) {
      el.classList.add(classNames)
    }

    for (const attrName in attributes) {
      el[attrName] = attributes[attrName]
    }

    return el
  }

  get data() {
    return this._data
  }

  /**
     * Set image data and update the view
     *
     * @param {SimpleImageData} data
     */
  set data(data) {
    this._data = Object.assign({}, this.data, data)
    // console.log('_data', this._data)
    if (this.nodes.image) {
      this.nodes.image.src = this._data.url
      this.nodes.plusHolder.style.display = 'none'
      // console.log(this.nodes.image)
    }
  }

  static get isReadOnlySupported() {
    return true
  }

  static get toolbox() {
    return {
      title: 'ImageTool',
      icon: '<?xml version="1.0" standalone="no"?><!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd"><svg t="1711445018253" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="2452" width="32" height="32" xmlns:xlink="http://www.w3.org/1999/xlink"><path d="M91.428571 731.428571a18.285714 18.285714 0 0 1-11.702857-32.548571l201.142857-164.571429a18.285714 18.285714 0 0 1 23.04 0l169.325715 135.314286 207.725714-242.834286a18.285714 18.285714 0 0 1 25.6-1.828571l237.714286 201.142857a18.285714 18.285714 0 0 1-23.405715 27.794286l-223.817142-189.44-207.725715 242.468571a18.285714 18.285714 0 0 1-25.234285 2.194286L292.571429 571.977143l-189.44 155.428571a20.48 20.48 0 0 1-11.702858 4.022857z" p-id="2453"></path><path d="M932.571429 896h-841.142858A18.285714 18.285714 0 0 1 73.142857 877.714286V146.285714a18.285714 18.285714 0 0 1 18.285714-18.285714h841.142858a18.285714 18.285714 0 0 1 18.285714 18.285714v731.428572a18.285714 18.285714 0 0 1-18.285714 18.285714zM109.714286 859.428571h804.571428v-694.857142H109.714286z" p-id="2454"></path><path d="M438.857143 457.142857a91.428571 91.428571 0 1 1 91.428571-91.428571 91.428571 91.428571 0 0 1-91.428571 91.428571z m0-146.285714a54.857143 54.857143 0 1 0 54.857143 54.857143A54.857143 54.857143 0 0 0 438.857143 310.857143z" p-id="2455"></path></svg>'
    }
  }
  save(blockContent) {
    // console.log(blockContent)
    const image = blockContent.querySelector('img')
    // caption = blockContent.querySelector('.' + this.CSS.input);

    if (!image) {
      return this.data
    }

    const r = Object.assign(this.data, {
      url: image.src
      // caption: caption.innerHTML,
    })
    // console.log('returndata', r)
    return r
  }

  renderSettings() {
    return this.tunes.map(tune => ({
      ...tune,
      label: this.api.i18n.t(tune.label),
      toggle: true,
      onActivate: () => this._toggleTune(tune.name),
      isActive: !!this.data[tune.name]
    }))
  }
  _toggleTune(tune) {
    this.data[tune] = !this.data[tune]
    this._acceptTuneView()
  }

  /**
     * Add specified class corresponds with activated tunes
     *
     * @private
     */
  _acceptTuneView() {
    this.tunes.forEach(tune => {
      this.nodes.imageHolder.classList.toggle(this.CSS.imageHolder + '--' + tune.name.replace(/([A-Z])/g, (g) => `-${g[0].toLowerCase()}`), !!this.data[tune.name])

      if (tune.name === 'stretched') {
        this.api.blocks.stretchBlock(this.blockIndex, !!this.data.stretched)
      }
    })
  }
}
