import { IconPlay } from '@codexteam/icons'
import './index.css'
import videojs from 'video.js'
import 'video.js/dist/video-js.css'
export default class VideoTool {
  constructor({ data, block, config, api }) {
    /**
         * Nodes cache
         */

    this.nodes = {
      wrapper: null,
      video: null,
      plusHolder: null,
      popOver: null,
      videoSource: null
    }
    this.api = api
    this.player = null
    this.data = {
      src: data.src || '',
      withBorder: data.withBorder !== undefined ? data.withBorder : false,
      withBackground: data.withBackground !== undefined ? data.withBackground : false,
      stretched: data.stretched !== undefined ? data.stretched : false

    }
    // console.log('thisdata', this.data)
    this.config = config
    this.block = block
  }

  static get toolbox() {
    return {
      title: 'VideoPlayer',
      icon: IconPlay
    }
  }

  changeImageUrl(url) {
    this.data = {
      src: url
    }
  }
  afterRender() {
    // videojs(`vedio_${this.block.id}`)
  }
  render() {
    this.nodes.wrapper = this._make('div', '', { style: 'height:100px;' })
    this.nodes.video = this._make('video', 'video-js', { style: 'display:none;width:100%;', id: `vedio_${this.block.id}` })
    this.nodes.videoSource = this._make('source', '', { type: 'video/mp4' })
    this.nodes.video.appendChild(this.nodes.videoSource)
    this.nodes.wrapper.classList.add('wrapper')
    this.nodes.video.setAttribute('controls', '')
    this.nodes.video.setAttribute('preload', '')
    this.nodes.plusHolder = this._make('div', 'cdx-plus-holder', {
      onclick: () => {
        this.config.onChoose(this.block.id, this.api.blocks.getCurrentBlockIndex())
      }
    })
    const plus = this._make('i', ['el-icon-plus'], {})
    this.nodes.plusHolder.appendChild(plus)
    // this.nodes.input.type = 'text'
    // this.nodes.input.name = 'audioUrl'
    // this.nodes.input.placeholder = 'Enter your url of audio file'
    // this.nodes.input.value = this.data.src ? this.data.src : ''
    // this.nodes.input.classList.add('input')
    // this.nodes.input.addEventListener('change', () => {
    //   const src = this.nodes.input?.value
    //   if (src) {
    //     this.nodes.audio.setAttribute('src', src)
    //   } else {
    //     this.nodes.audio.removeAttribute('src')
    //   }
    // })
    if (this.data.src) {
      this.nodes.videoSource.setAttribute('src', this.data.src)
    }
    // const { src } = this.data
    // if (src) {
    //
    // }

    // this.nodes.wrapper.appendChild(this.nodes.input)
    this.nodes.wrapper.appendChild(this.nodes.video)
    this.nodes.wrapper.appendChild(this.nodes.plusHolder)

    if (this.data.src) {
      this.nodes.videoSource.src = this.data.src
      this.nodes.plusHolder.style.display = 'none'
      this.nodes.video.style.display = 'block'
      this.nodes.wrapper.style.height = '500px'
      const id = this.block.id

      setTimeout(() => {
        this.player = videojs(`vedio_${id}`)
      }, 500)
      //
    } else {
      this.nodes.video.style.display = 'none'
      this.nodes.wrapper.style.height = '100px'
      this.nodes.plusHolder.style.display = 'block'
    }

    return this.nodes.wrapper
  }

  save(blockContent) {
    const video = blockContent.querySelector('video')
    const src = video.querySelector('source').src

    return {
      src
    }
  }

  validate(savedData) {
    if (savedData.src === '' && !savedData.src.trim()) {
      return false
    }

    return true
  }

  _make(tagName, classNames = null, attributes = {}) {
    const el = document.createElement(tagName)

    if (Array.isArray(classNames)) {
      el.classList.add(...classNames)
    } else if (classNames) {
      el.classList.add(classNames)
    }

    for (const attrName in attributes) {
      el[attrName] = attributes[attrName]
    }

    return el
  }

  get data() {
    return this._data
  }
  static get isReadOnlySupported() {
    return true
  }
  set data(data) {
    // console.log('setdata')
    this._data = Object.assign({}, this.data, data)
    if (this.nodes.video && this.nodes.videoSource) {
      if (this._data.src) {
        this.nodes.videoSource.src = this._data.src
        this.nodes.plusHolder.style.display = 'none'
        this.nodes.video.style.display = 'block'
        this.nodes.wrapper.style.height = '500px'
        const id = this.block.id
        setTimeout(function() {
          videojs(`vedio_${id}`)
        }, 500)
        // console.log(this.nodes.video)
      } else {
        this.nodes.video.style.display = 'none'
        this.nodes.plusHolder.style.display = 'block'
        this.nodes.wrapper.style.height = '100px'
      }
    }
  }
  destroy() {
    if (this.player) {
      this.player.dispose()
    }
  }
}
