
import { buildRequester } from './utils/ajax.js'
import { format as filesizeDefault, metricFormat as filesizeMetric } from './utils/filesize.js'
import { useStorage } from './composables/useStorage.js'
import { FEATURE_ALL_NAMES, FEATURES } from './features.js'
import useTheme from './composables/useTheme.js'
export default (props, options) => {
  const storage = useStorage(props.id)
  const metricUnits = storage.getStore('metricUnits', true)
  const theme = useTheme(storage, props.theme)
  // const supportedLocales = options.i18n
  // const initialLang = props.locale ?? options.locale

  const setFeatures = (features) => {
    if (Array.isArray(features)) {
      return features
    }
    return FEATURE_ALL_NAMES
  }

  const path = props.persist ? storage.getStore('path', props.path) : props.path

  return {
    // app version
    version: '1.0.1',
    // root element
    root: null,
    // app id
    debug: props.debug,
    // // Event Bus
    // emitter: emitter,
    // active features
    features: setFeatures(FEATURE_ALL_NAMES),
    // http object
    requester: buildRequester(props.request),
    // theme state
    theme: theme,
    // view state
    view: storage.getStore('viewport', 'grid'),
    // fullscreen state
    fullScreen: storage.getStore('full-screen', props.fullScreen),
    // selectButton state
    selectButton: props.selectButton,
    // unit state - for example: GB or GiB
    metricUnits: metricUnits,
    // human readable file sizes
    filesize: metricUnits ? filesizeMetric : filesizeDefault,
    // max file size
    maxFileSize: props.maxFileSize,
    // loading state
    loading: false,
    // default locale
    // i18n: i18n,
    // modal state
    modal: {
      active: false,
      type: 'delete',
      data: {}
    },
    // main storage adapter
    adapter: storage.getStore('adapter'),
    // main storage adapter
    path: path,
    // persist state
    persist: props.persist,
    // storage
    storage: storage,
    breadcrumb: [],
    // fetched items
    data: { adapter: storage.getStore('adapter'), storages: [], dirname: path, files: [], paths: [] },
    // selected items
    selectedItems: []
  }
}
