const debounce = (fn, delay = 0, immediate = false) => {
  let timeout
  return (...args) => {
    if (immediate && !timeout) fn(...args)
    clearTimeout(timeout)

    timeout = setTimeout(() => {
      fn(...args)
    }, delay)
  }
}

const useDebouncedRef = (initialValue, delay, immediate) => {
  let state = initialValue
  return (track, trigger) => ({
    get() {
      track()
      return state
    },
    set: debounce(
      value => {
        state = value
        trigger()
      },
      delay,
      immediate
    )
  })
}

export default useDebouncedRef
